summaryrefslogtreecommitdiffstats
path: root/kwin/kcmkwin/kwinrules/kcm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/kcmkwin/kwinrules/kcm.cpp')
-rw-r--r--kwin/kcmkwin/kwinrules/kcm.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kwin/kcmkwin/kwinrules/kcm.cpp b/kwin/kcmkwin/kwinrules/kcm.cpp
index 90802c41d..c7cdc7587 100644
--- a/kwin/kcmkwin/kwinrules/kcm.cpp
+++ b/kwin/kcmkwin/kwinrules/kcm.cpp
@@ -28,10 +28,10 @@
#include "ruleslist.h"
extern "C"
- KDE_EXPORT KCModule *create_kwinrules( TQWidget *parent, const char *name )
+ KDE_EXPORT KCModule *create_twinrules( TQWidget *parent, const char *name )
{
- //CT there's need for decision: kwm or kwin?
- KGlobal::locale()->insertCatalogue( "kcmkwinrules" );
+ //CT there's need for decision: kwm or twin?
+ KGlobal::locale()->insertCatalogue( "kcmtwinrules" );
return new KWinInternal::KCMRules( parent, name );
}
@@ -40,13 +40,13 @@ namespace KWinInternal
KCMRules::KCMRules( TQWidget *parent, const char *name )
: KCModule( parent, name )
-, config( "kwinrulesrc" )
+, config( "twinrulesrc" )
{
TQVBoxLayout *layout = new TQVBoxLayout( this );
widget = new KCMRulesList( this );
layout->addWidget( TQT_TQWIDGET(widget) );
connect( widget, TQT_SIGNAL( changed( bool )), TQT_SLOT( moduleChanged( bool )));
- KAboutData *about = new KAboutData(I18N_NOOP( "kcmkwinrules" ),
+ KAboutData *about = new KAboutData(I18N_NOOP( "kcmtwinrules" ),
I18N_NOOP( "Window-Specific Settings Configuration Module" ),
0, 0, KAboutData::License_GPL, I18N_NOOP( "(c) 2004 KWin and KControl Authors" ));
about->addAuthor("Lubos Lunak",0,"l.lunak@kde.org");
@@ -64,11 +64,11 @@ void KCMRules::save()
{
widget->save();
emit KCModule::changed( false );
// Send signal to kwin
config.sync();
if( !kapp->dcopClient()->isAttached())
kapp->dcopClient()->attach();
- kapp->dcopClient()->send("kwin*", "", "reconfigure()", TQString(""));
+ kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
void KCMRules::defaults()
@@ -64,11 +64,11 @@ void KCMRules::save()
widget->save();
emit KCModule::changed( false );
- // Send signal to kwin
+ // Send signal to twin
config.sync();
if( !kapp->dcopClient()->isAttached())